PME+ discount every distribution by a factor computed so that the NAV of the
index investment matches the NAV of the fund. The PME+ returns an IRR value of
discounted distributions.

See also:
- `pme_plus_flows` and `pme_plus_lambda` functions
- <https://en.wikipedia.org/wiki/Public_Market_Equivalent#PME+>
- <https://blog.edda.co/advanced-fund-performance-methods-pme-direct-alpha/>
